@@ -128,7 +128,7 @@ class MinioAgent(ABC):
         df_generator = self.get_df_generator_for_objects_in_bucket(
             names=object_names_todo, bucket_name=bucket_name
         )
-        self.process(df_generator)
+        self.process_generator(df_generator)
         if not dry_run:
             self.tag_objects_as_processed(
                 object_names_processed=object_names_todo, bucket_name=bucket_name
